@@ -5,9 +5,14 @@ var annotated_dup =
     [ "client_data", "structclient__data.html", "structclient__data" ],
     [ "control", "structcontrol.html", "structcontrol" ],
     [ "data", "structdata.html", "structdata" ],
+    [ "default_node", "structdefault__node.html", "structdefault__node" ],
+    [ "device", "structdevice.html", "structdevice" ],
+    [ "endpoint", "structendpoint.html", "structendpoint" ],
+    [ "endpoint_link", "structendpoint__link.html", "structendpoint__link" ],
     [ "error_data", "structerror__data.html", "structerror__data" ],
     [ "factory_data", "structfactory__data.html", "structfactory__data" ],
     [ "filter", "structfilter.html", "structfilter" ],
+    [ "find_data", "structfind__data.html", "structfind__data" ],
     [ "find_node", "structfind__node.html", "structfind__node" ],
     [ "find_port", "structfind__port.html", "structfind__port" ],
     [ "graph", "structgraph.html", "structgraph" ],
@@ -32,10 +37,12 @@ var annotated_dup =
     [ "node_data", "structnode__data.html", "structnode__data" ],
     [ "object_data", "structobject__data.html", "structobject__data" ],
     [ "object_entry", "structobject__entry.html", "structobject__entry" ],
+    [ "object_info", "structobject__info.html", "structobject__info" ],
     [ "param", "structparam.html", "structparam" ],
     [ "param_filter", "structparam__filter.html", "structparam__filter" ],
     [ "plugin", "structplugin.html", "structplugin" ],
     [ "port", "structport.html", "structport" ],
+    [ "profile", "structprofile.html", "structprofile" ],
     [ "protocol_data", "structprotocol__data.html", "structprotocol__data" ],
     [ "pw_array", "structpw__array.html", "structpw__array" ],
     [ "pw_buffer", "structpw__buffer.html", "structpw__buffer" ],
@@ -110,10 +117,13 @@ var annotated_dup =
     [ "pwtest_test", "structpwtest__test.html", null ],
     [ "queue", "structqueue.html", "structqueue" ],
     [ "registry", "structregistry.html", "structregistry" ],
+    [ "registry_event", "structregistry__event.html", "structregistry__event" ],
     [ "resource_data", "structresource__data.html", "structresource__data" ],
     [ "result_device_params_data", "structresult__device__params__data.html", "structresult__device__params__data" ],
     [ "result_node_params_data", "structresult__node__params__data.html", "structresult__node__params__data" ],
     [ "result_port_params_data", "structresult__port__params__data.html", "structresult__port__params__data" ],
+    [ "route", "structroute.html", "structroute" ],
+    [ "route_info", "structroute__info.html", "structroute__info" ],
     [ "server", "structserver.html", "structserver" ],
     [ "spa_audio_info", "structspa__audio__info.html", "structspa__audio__info" ],
     [ "spa_audio_info_dsp", "structspa__audio__info__dsp.html", "structspa__audio__info__dsp" ],
@@ -252,6 +262,7 @@ var annotated_dup =
     [ "spa_video_info_raw", "structspa__video__info__raw.html", "structspa__video__info__raw" ],
     [ "stream", "structstream.html", "structstream" ],
     [ "support", "structsupport.html", "structsupport" ],
+    [ "sync", "structsync.html", "structsync" ],
     [ "thread", "structthread.html", "structthread" ],
     [ "tunnel", "structtunnel.html", "structtunnel" ],
     [ "tunnel_info", "structtunnel__info.html", "structtunnel__info" ]
